==> huaweicloudsdkdataartsstudio-3.1.68-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/show_instance_log_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowInstanceLogRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workspace': 'str',
        'task_id': 'str',
        'instance_id': 'str',
        'body': 'JobLogRequest'
    }

    attribute_map = {
        'workspace': 'workspace',
        'task_id': 'task_id',
        'instance_id': 'instance_id',
        'body': 'body'
    }

    def __init__(self, workspace=None, task_id=None, instance_id=None, body=None):
        """ShowInstanceLogRequest

        The model defined in huaweicloud sdk

        :param workspace: DataArts Studio工作空间ID
        :type workspace: str
        :param task_id: 例ID
        :type task_id: str
        :param instance_id: 事例ID
        :type instance_id: str
        :param body: Body of the ShowInstanceLogRequest
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.JobLogRequest`
        """
        
        

        self._workspace = None
        self._task_id = None
        self._instance_id = None
        self._body = None
        self.discriminator = None

        self.workspace = workspace
        self.task_id = task_id
        self.instance_id = instance_id
        if body is not None:
            self.body = body

    @property
    def workspace(self):
        """Gets the workspace of this ShowInstanceLogRequest.

        DataArts Studio工作空间ID

        :return: The workspace of this ShowInstanceLogRequest.
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this ShowInstanceLogRequest.

        DataArts Studio工作空间ID

        :param workspace: The workspace of this ShowInstanceLogRequest.
        :type workspace: str
        """
        self._workspace = workspace

    @property
    def task_id(self):
        """Gets the task_id of this ShowInstanceLogRequest.

        例ID

        :return: The task_id of this ShowInstanceLogRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this ShowInstanceLogRequest.

        例ID

        :param task_id: The task_id of this ShowInstanceLogRequest.
        :type task_id: str
        """
        self._task_id = task_id

    @property
    def instance_id(self):
        """Gets the instance_id of this ShowInstanceLogRequest.

        事例ID

        :return: The instance_id of this ShowInstanceLogRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ShowInstanceLogRequest.

        事例ID

        :param instance_id: The instance_id of this ShowInstanceLogRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def body(self):
        """Gets the body of this ShowInstanceLogRequest.

        :return: The body of this ShowInstanceLogRequest.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.JobLogRequest`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ShowInstanceLogRequest.

        :param body: The body of this ShowInstanceLogRequest.
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.JobLogRequest`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowInstanceLogRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/show_instance_log_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowInstanceLogRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workspace': 'str',
        'task_id': 'str',
        'instance_id': 'str',
        'body': 'JobLogRequest'
    }

    attribute_map = {
        'workspace': 'workspace',
        'task_id': 'task_id',
        'instance_id': 'instance_id',
        'body': 'body'
    }

    def __init__(self, workspace=None, task_id=None, instance_id=None, body=None):
        r"""ShowInstanceLogRequest

        The model defined in huaweicloud sdk

        :param workspace: DataArts Studio工作空间ID
        :type workspace: str
        :param task_id: 例ID
        :type task_id: str
        :param instance_id: 事例ID
        :type instance_id: str
        :param body: Body of the ShowInstanceLogRequest
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.JobLogRequest`
        """
        
        

        self._workspace = None
        self._task_id = None
        self._instance_id = None
        self._body = None
        self.discriminator = None

        self.workspace = workspace
        self.task_id = task_id
        self.instance_id = instance_id
        if body is not None:
            self.body = body

    @property
    def workspace(self):
        r"""Gets the workspace of this ShowInstanceLogRequest.

        DataArts Studio工作空间ID

        :return: The workspace of this ShowInstanceLogRequest.
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        r"""Sets the workspace of this ShowInstanceLogRequest.

        DataArts Studio工作空间ID

        :param workspace: The workspace of this ShowInstanceLogRequest.
        :type workspace: str
        """
        self._workspace = workspace

    @property
    def task_id(self):
        r"""Gets the task_id of this ShowInstanceLogRequest.

        例ID

        :return: The task_id of this ShowInstanceLogRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        r"""Sets the task_id of this ShowInstanceLogRequest.

        例ID

        :param task_id: The task_id of this ShowInstanceLogRequest.
        :type task_id: str
        """
        self._task_id = task_id

    @property
    def instance_id(self):
        r"""Gets the instance_id of this ShowInstanceLogRequest.

        事例ID

        :return: The instance_id of this ShowInstanceLogRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        r"""Sets the instance_id of this ShowInstanceLogRequest.

        事例ID

        :param instance_id: The instance_id of this ShowInstanceLogRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def body(self):
        r"""Gets the body of this ShowInstanceLogRequest.

        :return: The body of this ShowInstanceLogRequest.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.JobLogRequest`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this ShowInstanceLogRequest.

        :param body: The body of this ShowInstanceLogRequest.
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.JobLogRequest`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowInstanceLogRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
